@@ -123,9 +123,9 @@ orsk <-
 
       tmp <- 1:max(2, ceiling(0.1*min(x-1, y-1))) # select number of random integer
       p0 <- cbind(sample(y-1)[tmp], sample(x-1)[tmp])
-      sink("/dev/null")
-      ans <- multiStart(par=p0, fn=fw, lower=c(1,1), upper=c(x-1,y-1), action="optimize", control=list(trace=FALSE), quiet=TRUE)
-      sink()
+#      sink("/dev/null")
+      ans <- multiStart(par=p0, fn=fw, lower=c(1,1), upper=c(x-1,y-1), action="optimize", control=list(trace=FALSE), quiet=TRUE, details=FALSE)
+#      sink()
 #      ans <- multiStartNew(par=p0, fn=fw, lower=c(1,1), upper=c(x-1,y-1), action="optimize", control=list(trace=FALSE), quiet=TRUE)
       pmat <- ans$par[ans$conv, ]
       pmat <- round(pmat)
